Documentation
¶
Index ¶
- Variables
- type Config
- type Solver
- func (s *Solver) CleanUp(ch *v1alpha1.ChallengeRequest) error
- func (s *Solver) Error(err error, msg string, args ...any)
- func (s *Solver) Initialize(kubeClientConfig *rest.Config, stopCh <-chan struct{}) error
- func (s *Solver) Name() string
- func (s *Solver) Present(ch *v1alpha1.ChallengeRequest) error
- func (s *Solver) SetLogLevel(level string) error
Constants ¶
This section is empty.
Variables ¶
var ( ErrNeedSecretName = errors.New("secret name must be specified") ErrNeedSecretKey = errors.New("secret key must be specified") )
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
TTL *uint64 `json:"ttl"`
RecordLine string `json:"recordLine"`
SecretIdRef cmmeta.SecretKeySelector `json:"secretIdRef"`
SecretKeyRef cmmeta.SecretKeySelector `json:"secretKeyRef"`
}
Config represents the configuration of dnspod resolver
type Solver ¶
type Solver struct {
// contains filtered or unexported fields
}
Solver implements the logic needed to 'present'an ACME challenge TXT record for dnspod.
func (*Solver) CleanUp ¶
func (s *Solver) CleanUp(ch *v1alpha1.ChallengeRequest) error
CleanUp should delete the relevant TXT record from the DNS provider console. If multiple TXT records exist with the same record name (e.g. _acme-challenge.example.com) then **only** the record with the same `key` value provided on the ChallengeRequest should be cleaned up. This is in order to facilitate multiple DNS validations for the same domain concurrently.
func (*Solver) Initialize ¶
Initialize will be called when the webhook first starts. This method can be used to instantiate the webhook, i.e. initialising connections or warming up caches. Typically, the kubeClientConfig parameter is used to build a Kubernetes client that can be used to fetch resources from the Kubernetes API, e.g. Secret resources containing credentials used to authenticate with DNS provider accounts. The stopCh can be used to handle early termination of the webhook, in cases where a SIGTERM or similar signal is sent to the webhook process.
func (*Solver) Name ¶
Name is used as the name for this DNS solver when referencing it on the ACME Issuer resource.
func (*Solver) Present ¶
func (s *Solver) Present(ch *v1alpha1.ChallengeRequest) error
Present is responsible for actually presenting the DNS record with the DNS provider. This method should tolerate being called multiple times with the same value. cert-manager itself will later perform a self check to ensure that the solver has correctly configured the DNS provider.